==> thx_sphinx-0.6-py3-none-any.whl: thx/sphinx/docs.py <==
# coding: utf-8
"""
Documentation
=============


Documentation is written with Sphinx...

"""


def get_jumbo_menu_entry(app_label=''):
    """Return a tuple suitable as dropdown specification for thux theme

    :arg app_label: an app_label suitable for intersphinx specs
    """
    if app_label:
        app_label = app_label + ":"
    return ("Jumbo", {
        'sub': [
            ('Framework', {'ref': '{}index'.format(app_label)}),
            ('--', ''),
            ('Quickstart', {'ref': '{}quickstart'.format(app_label)}),
            ('Buildout', {'ref': '{}buildout-env'.format(app_label)}),
            ('Utils', {'ref': '{}buildout-utilities'.format(app_label)}),
            ('Mercurial', {'ref': 'mercurial'.format(app_label)}),
            ('Cookiecutters', {'ref': 'cookiecutters'.format(app_label)}),
            ('Troubleshooting', {'ref': '{}troubleshooting'.format(app_label)}),
            ('--', ''),
            #('Writing Documentation', {'ref': '{}use-sphinx'.format(app_label)}),
            ('Scrivere documentazione', {'ref': 'docs'.format(app_label)}),
        ]
    })


def get_packages_menu_entry(app_label=''):
    """Return a tuple suitable as dropdown specification for jumbo theme

    :arg app_label: an app_label suitable for intersphinx specs
    """
    if app_label:
        app_label = app_label + ":"
    return ("Packages", {
        'sub': [
            ('thx-sso-client', {'href': 'http://docs.thux.it/thx-sso-client', 'static': True}),
            ('--', ''),
            ('jmb.core', {'href': 'http://docs.thux.it/jmb.core', 'static': True}),
            ('jmb.jadmin', {'href': 'http://docs.thux.it/jmb.jadmin', 'static': True}),
            ('jmb.filters', {'href': 'http://docs.thux.it/jmb.filters', 'static': True}),
            ('docs', {'href': 'http://docs.thux.it/thx-docs', 'static': True}),
            ('--', ''),
            ('jmb.async', {'href': 'http://docs.thux.it/jmb.async', 'static': True}),
            ('jmb.fax', {'href': 'http://docs.thux.it/jmb.fax', 'static': True}),
            ('jmb.ticket', {'href': 'http://docs.thux.it/jmb.ticket', 'static': True}),
            #            ('jmb.news', {'href' : 'http://docs.thux.it/jmb.news', 'static':True}),
            ('jmb.webposte', {'href': 'http://docs.thux.it/jmb.webposte', 'static': True}),
            ('jmb.newsletter', {'href': 'http://docs.thux.it/jmb.newsletter', 'static': True}),
            ('--', ''),
            ('poste-online', {'href': 'http://docs.thux.it/poste-online', 'static': True}),
        ]
    })


def get_intersphinx_mapping():
    """A standard intersphinx mapping for our projetcs
    Read how to use itin the `official docs`_

    .. _`official docs`: https://www.sphinx-doc.org/en/master/usage/extensions/intersphinx.html

    """
    return {
        'jmbcore': ('https://docs.thux.it/jmb.core/', None),
        'tools': ('https://docs.thux.it/jmb-tools/', None),
        'jadmin': ('https://docs.thux.it/jmb.jadmin/', None),
        'jfax': ('https://docs.thux.it/jmb.fax/', None),
        'tools': ('https://docs.thux.it/jmb-tools/', None),
        'hg': ('https://docs.thux.it/thx-docs/', None),
        'https://docs.python.org/': None,
    }

==> thx_sphinx-0.6.2-py3-none-any.whl: thx/sphinx/docs.py <==
# coding: utf-8
"""
Documentation
=============


Documentation is written with Sphinx...

"""


def get_jumbo_menu_entry(app_label=''):
    """Return a tuple suitable as dropdown specification for thux theme

    :arg app_label: an app_label suitable for intersphinx specs
    """
    if app_label:
        app_label = app_label + ":"
    return ("Jumbo", {
        'sub': [
            ('Framework', {'ref': '{}index'.format(app_label)}),
            ('--', ''),
            ('Quickstart', {'ref': '{}quickstart'.format(app_label)}),
            ('Buildout', {'ref': '{}buildout-env'.format(app_label)}),
            ('Utils', {'ref': '{}buildout-utilities'.format(app_label)}),
            ('jmb tools', {'href': 'https://docs.thux.it/jmb-tools/', 'static': True}),
            ('Mercurial', {'ref': 'mercurial'.format(app_label)}),
            ('Cookiecutters', {'ref': 'cookiecutters'.format(app_label)}),
            ('Troubleshooting', {'ref': '{}troubleshooting'.format(app_label)}),
            ('--', ''),
            #('Writing Documentation', {'ref': '{}use-sphinx'.format(app_label)}),
            ('Scrivere documentazione', {'ref': 'docs'.format(app_label)}),
        ]
    })


def get_packages_menu_entry(app_label=''):
    """Return a tuple suitable as dropdown specification for jumbo theme

    :arg app_label: an app_label suitable for intersphinx specs
    """
    if app_label:
        app_label = app_label + ":"
    return ("Packages", {
        'sub': [
            ('thx-docs', {'href': 'http://docs.thux.it/thx-docs', 'static': True}),
            ('jmb-tools', {'href': 'http://docs.thux.it/jmb-tools', 'static': True}),
            ('thx-tests', {'href': 'http://docs.thux.it/thx-tests', 'static': True}),
            ('thx-sso-client', {'href': 'http://docs.thux.it/thx-sso-client', 'static': True}),
            ('--', ''),
            ('jmb.core', {'href': 'http://docs.thux.it/jmb.core', 'static': True}),
            ('jmb.jadmin', {'href': 'http://docs.thux.it/jmb.jadmin', 'static': True}),
            ('jmb.filters', {'href': 'http://docs.thux.it/jmb.filters', 'static': True}),
            ('--', ''),
            ('jmb.async', {'href': 'http://docs.thux.it/jmb.async', 'static': True}),
            #('jmb.fax', {'href': 'http://docs.thux.it/jmb.fax', 'static': True}),
            #('jmb.ticket', {'href': 'http://docs.thux.it/jmb.ticket', 'static': True}),
            #            ('jmb.news', {'href' : 'http://docs.thux.it/jmb.news', 'static':True}),
            ('jmb.webposte', {'href': 'http://docs.thux.it/jmb.webposte', 'static': True}),
            ('jmb.newsletter', {'href': 'http://docs.thux.it/jmb.newsletter', 'static': True}),
            ('--', ''),
            ('poste-online', {'href': 'http://docs.thux.it/poste-online', 'static': True}),
        ]
    })


def get_intersphinx_mapping():
    """A standard intersphinx mapping for our projetcs
    Read how to use itin the `official docs`_

    .. _`official docs`: https://www.sphinx-doc.org/en/master/usage/extensions/intersphinx.html

    """
    return {
        'jmbcore': ('https://docs.thux.it/jmb.core/', None),
        'tools': ('https://docs.thux.it/jmb-tools/', None),
        'jadmin': ('https://docs.thux.it/jmb.jadmin/', None),
        'jfax': ('https://docs.thux.it/jmb.fax/', None),
        'hg': ('https://docs.thux.it/thx-docs/', None),
        'https://docs.python.org/': None,
    }
